@@ -1,6 +1,6 @@
 from copy import deepcopy
 from pathlib import Path
-from typing import Any, Union
+from typing import Any, Dict, List, Tuple, Union
 from unittest.mock import Mock, patch
 
 from smartparams.smart import Smart
@@ -83,14 +83,14 @@ class TestSmartAccessCase(UnitCase):
         self.assertEqual('argument31', self.smart.params['arg3']['arg31'])
         self.assertEqual('a32', self.smart.params['arg3']['arg32'])
 
-    @patch('smartparams.smart.load')
-    def test_update(self, load: Mock) -> None:
-        dictionary = {'arg3': {'arg31': 'argument31'}, 'arg4': 'argument4'}
-        load.return_value = dictionary
-        test_cases: list[tuple[Union['Smart', dict[str, Any], list[str], Path], str]] = [
+    @patch('smartparams.smart.load_data')
+    def test_update(self, load_data: Mock) -> None:
+        dictionary = {'arg1': {'nested1': 'argument1'}, 'arg3': {'arg31': 'argument31'}}
+        load_data.return_value = dictionary
+        test_cases: List[Tuple[Union['Smart', Dict[str, Any], List[str], Path], str]] = [
             (Smart(**dictionary), "smart"),
             (dictionary, "dict"),
-            (['arg3.arg31=argument31', 'arg4=argument4'], "list"),
+            (['arg3.arg31=argument31', 'arg1={"nested1": "argument1"}'], "list"),
             (Path('path/to/file.yaml'), "path"),
         ]
 
@@ -103,12 +103,36 @@ class TestSmartAccessCase(UnitCase):
                 self.assertTrue('arg1' in smart.params)
                 self.assertTrue('arg2' in smart.params)
                 self.assertTrue('arg3' in smart.params)
-                self.assertTrue('arg4' in smart.params)
-                self.assertEqual('arg1', smart.params['arg1'])
+                self.assertEqual({'nested1': 'argument1'}, smart.params['arg1'])
                 self.assertListEqual(['arg2'], smart.params['arg2'])
                 self.assertEqual('argument31', smart.params['arg3']['arg31'])
                 self.assertEqual('a32', smart.params['arg3']['arg32'])
-                self.assertEqual('argument4', smart.params['arg4'])
+
+    @patch('smartparams.smart.load_data')
+    def test_update__not_override(self, load_data: Mock) -> None:
+        dictionary = {'arg1': {'nested1': 'aa1'}, 'arg3': {'arg31': 'aa31'}, 'arg4': {'a4': 'aa4'}}
+        load_data.return_value = dictionary
+        test_cases: List[Tuple[Union['Smart', Dict[str, Any], List[str], Path], str]] = [
+            (Smart(**dictionary), "smart"),
+            (dictionary, "dict"),
+            (['arg3.arg31=argument31', 'arg1={"nested1": "aa1"}', 'arg4={"a4": "aa4"}'], "list"),
+            (Path('path/to/file.yaml'), "path"),
+        ]
+
+        for source, msg in test_cases:
+            smart: Smart = deepcopy(self.smart)
+
+            with self.subTest(msg=msg):
+                smart.update(source, override=False)
+
+                self.assertTrue('arg1' in smart.params)
+                self.assertTrue('arg2' in smart.params)
+                self.assertTrue('arg3' in smart.params)
+                self.assertEqual('arg1', smart.params['arg1'])
+                self.assertListEqual(['arg2'], smart.params['arg2'])
+                self.assertEqual('a31', smart.params['arg3']['arg31'])
+                self.assertEqual('a32', smart.params['arg3']['arg32'])
+                self.assertEqual({'a4': 'aa4'}, smart.params['arg4'])
 
     def test_update__unknown(self) -> None:
         source = tuple()  # type: ignore
@@ -187,14 +211,14 @@ class TestSmartInstantiateCase(UnitCase):
     def test_instantiate__any(self) -> None:
         data = "string"
 
-        result = self.smart._instantiate(data)
+        result = self.smart._instantiate(data, '')
 
         self.assertEqual(data, result)
 
     def test_instantiate__smart_dict(self) -> None:
         obj = self.params['smart_dict']
 
-        result = self.smart._instantiate(obj)
+        result = self.smart._instantiate(obj, '')
 
         self.assertIsInstance(result, Smart)
         self.assertIsNone(result.type)
@@ -202,7 +226,7 @@ class TestSmartInstantiateCase(UnitCase):
     def test_instantiate__smart(self) -> None:
         obj = self.params['smart']
 
-        result = self.smart._instantiate(obj)
+        result = self.smart._instantiate(obj, '')
 
         self.assertIsInstance(result, Smart)
         self.assertIs(result.type, Class)
@@ -211,26 +235,26 @@ class TestSmartInstantiateCase(UnitCase):
         obj = self.params['smart']
         obj['class'] += "suffix"  # type: ignore
 
-        self.assertRaises(ValueError, self.smart._instantiate, obj)
+        self.assertRaises(ValueError, self.smart._instantiate, obj, '')
 
     def test_instantiate__object(self) -> None:
         obj = self.params['object']
 
-        result = self.smart._instantiate(obj)
+        result = self.smart._instantiate(obj, '')
 
         self.assertIsInstance(result, Class)
 
     def test_instantiate__dict(self) -> None:
         obj = {'key': 'value'}
 
-        result = self.smart._instantiate(obj)
+        result = self.smart._instantiate(obj, '')
 
         self.assertIsNot(obj, result)
 
     def test_instantiate__list(self) -> None:
         obj = ['item']
 
-        result = self.smart._instantiate(obj)
+        result = self.smart._instantiate(obj, '')
 
         self.assertIsNot(obj, result)
 
@@ -241,7 +265,7 @@ class TestSmartInstantiateCase(UnitCase):
         obj = self.params['object']
         obj['class'] = 'Class'  # type: ignore
 
-        result = self.smart._instantiate(obj)
+        result = self.smart._instantiate(obj, '')
 
         self.assertIsInstance(result, Class)
 
@@ -250,7 +274,7 @@ class TestSmartInstantiateCase(UnitCase):
         self.smart._origins = {v: k for k, v in self.smart._aliases.items()}
         obj = self.params['object']
 
-        result = self.smart._instantiate(obj)
+        result = self.smart._instantiate(obj, '')
 
         self.assertIsInstance(result, Class)
 
@@ -260,66 +284,73 @@ class TestSmartInstantiateCase(UnitCase):
         self.smart._origins = {v: k for k, v in self.smart._aliases.items()}
         obj = self.params['object']
 
-        self.assertRaises(ImportError, self.smart._instantiate, obj)
+        self.assertRaises(ImportError, self.smart._instantiate, obj, '')
 
 
 class TestRegisterCase(UnitCase):
     def setUp(self) -> None:
-        self._aliases = Smart._aliases.copy()
-        self._origins = Smart._origins.copy()
-        self._allow_only_registered = Smart._allow_only_registered
-
-    def tearDown(self) -> None:
-        Smart._aliases = self._aliases.copy()
-        Smart._origins = self._origins.copy()
-        Smart._allow_only_registered = self._allow_only_registered
+        self.smart: Smart = Smart()
 
     def test_register__classes(self) -> None:
         classes = ('origin.1', 'origin.2')
 
-        Smart.register(classes)
+        self.smart.register(classes)
 
-        self.assertFalse(Smart._allow_only_registered)
-        self.assertEqual({'origin.1': 'origin.1', 'origin.2': 'origin.2'}, Smart._aliases)
-        self.assertEqual({'origin.1': 'origin.1', 'origin.2': 'origin.2'}, Smart._origins)
+        self.assertFalse(self.smart._allow_only_registered)
+        self.assertEqual({'origin.1': 'origin.1', 'origin.2': 'origin.2'}, self.smart._aliases)
+        self.assertEqual({'origin.1': 'origin.1', 'origin.2': 'origin.2'}, self.smart._origins)
 
     def test_register__aliases(self) -> None:
         aliases = {'origin.1': 'alias.1', 'origin.2': 'alias.2'}
 
-        Smart.register(aliases)
+        self.smart.register(aliases)
 
-        self.assertFalse(Smart._allow_only_registered)
-        self.assertEqual({'origin.1': 'alias.1', 'origin.2': 'alias.2'}, Smart._aliases)
-        self.assertEqual({'alias.1': 'origin.1', 'alias.2': 'origin.2'}, Smart._origins)
+        self.assertFalse(self.smart._allow_only_registered)
+        self.assertEqual({'origin.1': 'alias.1', 'origin.2': 'alias.2'}, self.smart._aliases)
+        self.assertEqual({'alias.1': 'origin.1', 'alias.2': 'origin.2'}, self.smart._origins)
 
-    @patch('smartparams.smart.warnings')
-    def test_register__duplicates(self, warnings: Mock) -> None:
-        Smart._aliases = {'origin.1': 'alias.1', 'origin.2': 'alias.2'}
-        Smart._origins = {'alias.1': 'origin.1', 'alias.2': 'origin.2'}
-        aliases = {'origin.1': 'alias.2'}
+    def test_register__alias_duplicates(self) -> None:
+        self.smart._aliases = {'origin': 'alias'}
+        self.smart._origins = {'alias': 'origin'}
+        aliases = {'origin.1': 'alias'}
 
-        Smart.register(aliases)
+        self.assertRaises(ValueError, self.smart.register, aliases)
 
-        self.assertEqual({'origin.1': 'alias.2'}, Smart._aliases)
-        self.assertEqual({'alias.2': 'origin.1'}, Smart._origins)
-        warnings.warn.assert_called()
+    def test_register__origin_duplicates(self) -> None:
+        self.smart._aliases = {'origin': 'alias'}
+        self.smart._origins = {'alias': 'origin'}
+        aliases = {'origin': 'alias.1'}
 
-    def test_register__allow_only_registered(self) -> None:
-        classes = ('origin.1', 'origin.2')
-
-        Smart.register(classes, allow_only_registered=True)
-
-        self.assertTrue(Smart._allow_only_registered)
-
-    @patch('smartparams.smart.warnings')
-    def test_register__disallow_only_registered(self, warnings: Mock) -> None:
-        Smart._allow_only_registered = True
-        classes = ('origin.1', 'origin.2')
-
-        Smart.register(classes, allow_only_registered=False)
-
-        self.assertTrue(Smart._allow_only_registered)
-        warnings.warn.assert_called()
+        self.assertRaises(ValueError, self.smart.register, aliases)
 
     def test_register__raise(self) -> None:
-        self.assertRaises(TypeError, Smart.register, Mock())
+        self.assertRaises(TypeError, self.smart.register, Mock())
+
+    def test_register__nested(self) -> None:
+        self.smart._location = 'nested'
+
+        self.assertRaises(AttributeError, self.smart.register, Mock())
+
+
+class TestConfigurationCase(UnitCase):
+    def setUp(self) -> None:
+        self.smart: Smart = Smart()
+
+    def test_configurate__allow_only_registered_true(self) -> None:
+        self.smart.configurate(
+            allow_only_registered=True,
+        )
+
+        self.assertTrue(self.smart._allow_only_registered)
+
+    def test_configurate__allow_only_registered_false(self) -> None:
+        self.smart.configurate(
+            allow_only_registered=False,
+        )
+
+        self.assertFalse(self.smart._allow_only_registered)
+
+    def test_configurate__allow_only_registered_false_raise(self) -> None:
+        self.smart._allow_only_registered = True
+
+        self.assertRaises(AttributeError, self.smart.configurate, allow_only_registered=False)
